@@ -35,23 +35,26 @@ impl Options {
 
 impl ThemeConfig {
     fn deduce<V: Vars>(vars: &V) -> Option<Self> {
-        if let Some(path) = vars.get("EZA_CONFIG_DIR") {
-            let path = PathBuf::from(path);
-            let path = path.join("theme.yml");
-            if path.exists() {
-                Some(ThemeConfig::from_path(&path.to_string_lossy()))
-            } else {
-                None
-            }
+        let (base_path, is_default_location) = if let Some(path) = vars.get("EZA_CONFIG_DIR") {
+            (PathBuf::from(path), false)
+        } else if let Some(path) = dirs::config_dir() {
+            (path.join("eza"), true)
         } else {
-            let path = dirs::config_dir().unwrap_or_default();
-            let path = path.join("eza").join("theme.yml");
-            if path.exists() {
-                Some(ThemeConfig::default())
+            return None;
+        };
+        let yml_path = base_path.join("theme.yml");
+        if yml_path.exists() {
+            return if is_default_location {
+                Some(ThemeConfig::from_path(&yml_path.to_string_lossy()))
             } else {
-                None
-            }
+                Some(ThemeConfig::default())
+            };
         }
+        let yaml_path = base_path.join("theme.yaml");
+        if yaml_path.exists() {
+            return Some(ThemeConfig::from_path(&yaml_path.to_string_lossy()));
+        }
+        None
     }
 }
 
