@@ -208,6 +208,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".condarc"            => '\u{e715}',            // 
     ".cshrc"              => Icons::SHELL,          // 󱆃
     ".DS_Store"           => Icons::OS_APPLE,       // 
+    ".editorconfig"       => '\u{e652}',            // 
     ".emacs"              => Icons::EMACS,          // 
     ".envrc"              => '\u{f462}',            // 
     ".eslintrc.cjs"       => Icons::ESLINT,         // 
@@ -558,7 +559,6 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "dylib"          => Icons::OS_APPLE,         // 
     "ebook"          => Icons::BOOK,             // 
     "ebuild"         => '\u{f30d}',              // 
-    "editorconfig"   => '\u{e652}',              // 
     "ejs"            => '\u{e618}',              // 
     "el"             => Icons::EMACS,            // 
     "elc"            => Icons::EMACS,            // 
